%--------------------
% MATLAB commands for joint use of mtmdofs.m and ftestmtm.m to demonstrate
% measurement of harmonic line frequency, amplitude and phase on two series
% with a single frequency differing by 90 phase. 
%
% NOTE: mtmdofs.m and ftestmtm.m will be merged into a single script soon!
%
% Point MATLAB to directory (folder) containing mtmdofs.m and ftestmtm.m;
% note that these two scripts require the MATLAB Signal Processing Toolbox
% and MATLAB Statistics Toolbox.
%
% TO RUN, PRESS 'RUN' BUTTON. TWO FIGURES ARE INCLUDED AS OUTPUT.
%
% Only phase is highlighted in this command sequence; another important
% output from ftestmtm.m is "ftest" which is the F-test ratio used to
% evaluate harmonic line significance level "fsig", also output.
%
%--------------------
%
% Set up time series w1 and w2 with N=1000 points, dt=0.1, timescale t, 
% sinusoid with frequency 1/10, 90-degree phase difference
%
N=1000; dt=0.1; t=0:dt:(N-1)*dt;t=t';
w1=cos(2*pi*t/10); %COSINE
w2=sin(2*pi*t/10); %SINE
%
% Harmonic analysis of w1 
%
% Apply mtmdofs.m to analyze adaptive weights wt1
% and degrees of freedom dof1 vs. frequency freq1;
% zero pad x 20 (npad=20); remove (mean and) linear trend;
% use 2pi multitapers (NW=2)
%
NW=2;
npad=20;
[freq1,dof1,wt1] = mtmdofs(t,detrend(w1),NW,npad);
%
% Apply ftestmtm.m to compute Amp1, ftest1, etc. 
% using output dof1 from mtmdofs.m
%
[freq1,ftest1,fsig1,Amp1,Faz1,Sig1,Noi1] = ftestmtm(t,detrend(w1),NW,dof1,npad);
%
% plot Amp1 and Faz1 together vs. freq1 on one display using MATLAB's plotyy
%
figure; [AX, H1, H2] = plotyy(freq1,Amp1,freq1,Faz1);
%
% limit x axis around the 1/10 frequency
% define tick marks for the two y axes
%
xlim([0.09 0.11]);ylim([0 1]);
xlim(AX(2),[0.09 0.11]);ylim(AX(2),[-180 180]); 
yticks([0 0.2 0.4 0.6 0.8 1.0]); 
yticks(AX(2),[-180 -135 -90 -45 0 45 90 135 180]);
title('2pi MTM Amplitude,Phase Spectra of w1=cos(2*pi*t/10)');
%
% Harmonic analysis of w2 
%
% Apply mtmdofs.m to analyze adaptive weights wt2
% and degrees of freedom dof2 vs. frequency freq2;
% zero pad x 20 (npad=20); remove (mean and) linear trend;
% use 2pi multitapers (NW=2)
%
NW=2;
npad=20;
[freq2,dof2,wt2] = mtmdofs(t,detrend(w2),NW,npad);
%
% Apply ftestmtm.m to compute Amp2, ftest2, etc. 
% using output dof2 from mtmdofs.m
%
[freq2,ftest2,fsig2,Amp2,Faz2,Sig2,Noi2] = ftestmtm(t,detrend(w2),NW,dof2,npad);
%
% plot Amp2 and Faz2 together vs. freq2 on one display using MATLAB's plotyy
%
figure; [AX, H1, H2] = plotyy(freq2,Amp2,freq2,Faz2);
%
% limit x axis around the 1/10 frequency
% define tick marks for the two y axes
%
xlim([0.09 0.11]);ylim([0 1]);
xlim(AX(2),[0.09 0.11]);ylim(AX(2),[-180 180]); 
yticks([0 0.2 0.4 0.6 0.8 1.0]); 
yticks(AX(2),[-180 -135 -90 -45 0 45 90 135 180]);
title('2pi MTM Amplitude,Phase Spectra of w2=sin(2*pi*t/10)');
%
% In both displays use cursor to identify phase at the amplitude maximum.
% 
%